@@ -19,10 +19,24 @@
 #
 #	Johannes Bauer <JohannesBauer@gmx.de>
 
+import logging
+
 class BaseAction():
 	def __init__(self, action, args):
 		self._action = action
 		self._args = args
+
+		if self._args.verbose == 0:
+			loglevel = logging.WARN
+		elif self._args.verbose == 1:
+			loglevel = logging.INFO
+		elif self._args.verbose == 2:
+			loglevel = logging.DEBUG
+		elif self._args.verbose == 3:
+			loglevel = logging.TRACE
+		elif self._args.verbose == 4:
+			loglevel = logging.SINGLESTEP
+		logging.basicConfig(format = " {name:>20s} [{levelname:.1s}]: {message}", style = "{", level = loglevel)
 		self.run()
 
 	def run(self):
